@@ -1,6 +1,6 @@
-#' Read a database described in a .sql file.
+#' @describeIn preinstalled.readers Read a database described in a \code{.sql} file.
 #'
-#' This function will load data from a SQL database based on configuration
+#' @details The \code{sql.reader} function will load data from a SQL database based on configuration
 #' information found in the specified .sql file. The .sql file must specify
 #' a database to be accessed. All tables from the database, one specific tables
 #' or one specific query against any set of tables may be executed to generate
@@ -101,18 +101,6 @@
 #' plugin: extension
 #' query: SELECT *,STDEV(value1) FROM example_table
 #'
-#' @param data.file The name of the data file to be read.
-#' @param filename The path to the data set to be loaded.
-#' @param variable.name The name to be assigned to in the global environment.
-#'
-#' @return No value is returned; this function is called for its side effects.
-#'
-#' @examples
-#' library('ProjectTemplate')
-#'
-#' \dontrun{sql.reader('example.sql', 'data/example.sql', 'example')}
-#'
-#' @include require.package.R
 #' @importFrom utils modifyList
 sql.reader <- function(data.file, filename, variable.name)
 {
@@ -174,6 +162,8 @@ sql.reader <- function(data.file, filename, variable.name)
                             dbname = database.info[['dbname']],
                             port = as.integer(database.info[['port']]),
                             unix.socket = database.info[['socket']])
+    on.exit(try(DBI::dbDisconnect(connection), silent = TRUE), add = TRUE)
+
     DBI::dbGetQuery(connection, "SET NAMES 'utf8'") # Switch to utf-8 strings
   }
 
@@ -185,6 +175,7 @@ sql.reader <- function(data.file, filename, variable.name)
 
     connection <- DBI::dbConnect(sqlite.driver,
                             dbname = database.info[['dbname']])
+    on.exit(try(DBI::dbDisconnect(connection), silent = TRUE), add = TRUE)
 
     if (!is.null(database.info[['plugin']]) && database.info[['plugin']] == 'extension')
     {
@@ -210,6 +201,7 @@ sql.reader <- function(data.file, filename, variable.name)
                             host = database.info[['host']],
                             dbname = database.info[['dbname']],
                             port = as.integer(database.info[['port']]))
+    on.exit(try(DBI::dbDisconnect(connection), silent = TRUE), add = TRUE)
   }
 
   if (database.info[['type']] == 'oracle')
@@ -228,6 +220,7 @@ sql.reader <- function(data.file, filename, variable.name)
                             user = database.info[['user']],
                             password = database.info[['password']],
                             dbname = database.info[['dbname']])
+    on.exit(try(DBI::dbDisconnect(connection), silent = TRUE), add = TRUE)
   }
 
   if (database.info[['type']] == 'jdbc')
@@ -247,6 +240,7 @@ sql.reader <- function(data.file, filename, variable.name)
                             database.info[['url']],
                             user = database.info[['user']],
                             password = database.info[['password']])
+    on.exit(try(DBI::dbDisconnect(connection), silent = TRUE), add = TRUE)
   }
 
   if (database.info[['type']] == 'heroku')
@@ -269,6 +263,7 @@ sql.reader <- function(data.file, filename, variable.name)
                             database.info[['url']],
                             user = database.info[['user']],
                             password = database.info[['password']])
+    on.exit(try(DBI::dbDisconnect(connection), silent = TRUE), add = TRUE)
   }
 
   # Added support for queries.
@@ -342,7 +337,7 @@ sql.reader <- function(data.file, filename, variable.name)
       query <- whisker::whisker.render(query, data = .GlobalEnv)
     }
     data.parcel <- try(DBI::dbGetQuery(connection, query))
-    err <- DBI::dbGetException(connection)
+    suppressWarnings(err <- DBI::dbGetException(connection))
 
     if (class(data.parcel) == 'data.frame' && (length(err) == 0 || err$errorNum == 0))
     {
@@ -375,13 +370,4 @@ sql.reader <- function(data.file, filename, variable.name)
            envir = .TargetEnv)
     return()
   }
-
-  # Disconnect from database resources. Warn if failure.
-  disconnect.success <- DBI::dbDisconnect(connection)
-
-  if (! disconnect.success)
-  {
-    warning(paste('Unable to disconnect from database:',
-                  database.info[['dbname']]))
-  }
 }
